/*
 * util.c -- Various error checking wrappers and utilities.
 *
 * Copyright (C) 2016 Tomasz Kramkowski <tk@the-tk.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <assert.h>
#include <errno.h>
#include <stdbool.h>
#include <stdint.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

#include "eprintf.h"
#include "util.h"

/* xstrmalloc: allocate for a string (+1) or exit with error */
void *xstrmalloc(size_t size)
{
	size_t nsize;

	if (size == SIZE_MAX)
		eprintf("xstrmalloc(%zu) failed: %zu == SIZE_MAX", size, size);

	return emalloc(nsize);
}

/* xstrcasecmp: case insensitive strcmp */
int xstrcasecmp(const char *s1, const char *s2)
{
	while (toupper(*s1++) == toupper(*s2++))
		if (*s1 == '\0' || *s2 == '\0')
			break;
	if (*s1 == *s2)
		return 0;
	if (*s1 < *s2)
		return -1;
	return 1;
}
